@@ -25,6 +25,4 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-extern crate tui;
-
-pub use tui::*;
+pub use tuirs::*;
